@@ -1,29 +1,10 @@
-from .connection import SAPConnection
-from .exceptions import SAPException
 from pyrfc import ABAPApplicationError, ABAPRuntimeError, LogonError, CommunicationError
 
+from sap_rfc_data_management.sap_generic import SAP
+from .exceptions import SAPException
 
-class PMEquipment:
-    def __init__(self,
-                 host: str,
-                 service: str,
-                 group: str,
-                 sysname: str,
-                 client: str,
-                 lang: str,
-                 user: str,
-                 password: str):
-        self.connection = SAPConnection(
-            host=host,
-            service=service,
-            group=group,
-            sysname=sysname,
-            client=client,
-            lang=lang,
-            user=user,
-            password=password
-        )
 
+class PMEquipment(SAP):
     def change(self,
                equipment: str,
                abc_code: str):
