@@ -1,45 +1,27 @@
 import datetime
 
-from .connection import SAPConnection
-from .exceptions import SAPException
 from pyrfc import ABAPApplicationError, ABAPRuntimeError, LogonError, CommunicationError
 
+from sap_rfc_data_management.sap_generic import SAP
+from .exceptions import SAPException, DefaultException
 
-class PMNotification:
-    def __init__(self,
-                 host: str,
-                 service: str,
-                 group: str,
-                 sysname: str,
-                 client: str,
-                 lang: str,
-                 user: str,
-                 password: str):
-        self.connection = SAPConnection(
-            host=host,
-            service=service,
-            group=group,
-            sysname=sysname,
-            client=client,
-            lang=lang,
-            user=user,
-            password=password
-        )
 
+class PMNotification(SAP):
     def create(self,
                notification_type: str,
-               equipment: str,
                maintenance_plant: str,
                title: str,
                reported_by: str,
                priority: str,
                workcenter_id: str,
-               date_malfunction: datetime.date):
+               date_malfunction: datetime.date = datetime.date.today(),
+               equipment: str = None,
+               functional_location: str = None,
+               longtext: str = None):
         try:
             connection = self.connection.get_connection()
-            create = connection.call(
-                'BAPI_ALM_NOTIF_CREATE',
-                NOTIFHEADER={
+            if equipment:
+                header = {
                     'EQUIPMENT': equipment.zfill(18),
                     'MAINTPLANT': maintenance_plant,
                     'SHORT_TEXT': title,
@@ -48,9 +30,42 @@ class PMNotification:
                     'STRMLFNDATE': date_malfunction.strftime('%Y%m%d'),
                     'PRIORITY': priority,
                     'PM_WKCTR': workcenter_id
-                },
-                NOTIF_TYPE=notification_type
-            )
+                }
+            elif functional_location:
+                header = {
+                    'FUNCT_LOC': functional_location,
+                    'MAINTPLANT': maintenance_plant,
+                    'SHORT_TEXT': title,
+                    'REPORTEDBY': reported_by,
+                    'NOTIF_DATE': datetime.date.today().strftime('%Y%m%d'),
+                    'STRMLFNDATE': date_malfunction.strftime('%Y%m%d'),
+                    'PRIORITY': priority,
+                    'PM_WKCTR': workcenter_id
+                }
+            else:
+                raise DefaultException('Equipment or functional location must be filled.')
+            if longtext:
+                longtext_object = []
+                splitted = [longtext[i:i+130] for i in range(0, len(longtext), 130)]
+                for sp in splitted:
+                    longtext_object.append(
+                        {
+                            'OBJTYPE': 'QMEL',
+                            'TEXT_LINE': sp
+                        }
+                    )
+                create = connection.call(
+                    'BAPI_ALM_NOTIF_CREATE',
+                    NOTIFHEADER=header,
+                    LONGTEXTS=longtext_object,
+                    NOTIF_TYPE=notification_type
+                )
+            else:
+                create = connection.call(
+                    'BAPI_ALM_NOTIF_CREATE',
+                    NOTIFHEADER=header,
+                    NOTIF_TYPE=notification_type
+                )
 
             return_messages = create['RETURN']
             if return_messages:
